Buttons Example
===============================================================================

:download:`buttons.enaml <../../../examples/widgets/buttons.enaml>`

.. literalinclude:: ../../../examples/widgets/buttons.enaml
    :language: python

::

 $ enaml-run buttons.enaml

.. image:: images/buttons.png
